Install aif360 and its dependencies
install_aif360(
method = c("auto", "virtualenv", "conda"),
conda = "auto",
version = "default",
envname = NULL,
extra_packages = NULL,
restart_session = TRUE,
conda_python_version = "3.7",
...
)Installation method. By default, "auto" automatically finds a method that will work in the local environment. Change the default to force a specific installation method. Note that the "virtualenv" method is not available on Windows. Note also that since this command runs without privilege the "system" method is available only on Windows.
The path to a conda executable. Use "auto" to allow reticulate to
automatically find an appropriate conda binary. See Finding Conda for more details.
AIF360 version to install. Specify "default" to install the latest release.
Name of Python environment to install within
Additional Python packages to install.
Restart R session after installing (note this will only occur within RStudio).
the python version installed in the created conda environment. Python 3.6 is installed by default.
other arguments passed to [reticulate::conda_install()] or [reticulate::virtualenv_install()].